class Employee:
    'Common base class for all employees'
    empCount = 0
    
    def __init__(self, name, salary):
        self.name = name 
        self.salary = salary 
        Employee.empCount += 1

    def displayCount(self):
        print "Total Employee %d" % Employee.empCount

    def displayEmployee(self):
        print "Name : ", self.name, ", Salary: ", self.salary



from distutils.core import setup

setup(
	name = 'strathxx',
	version = '1.0.0',
	py_modules = ['emp'],
	author = 'Troon',
	author_email = 'jayombagi@gmail.com',
	url = 'http://www.prewired.co.ke',
	description = 'Demo package for @iLabAfrica ISS',

)
